Module: LighterpackParser

Defined in:
lib/lighterpack_parser.rb,
lib/lighterpack_parser/item.rb,
lib/lighterpack_parser/list.rb,
lib/lighterpack_parser/parser.rb,
lib/lighterpack_parser/version.rb,
lib/lighterpack_parser/category.rb,
lib/lighterpack_parser/item_parser.rb,
lib/lighterpack_parser/list_parser.rb,
lib/lighterpack_parser/gram_converter.rb,
lib/lighterpack_parser/category_parser.rb

Overview

Parser for extracting data from Lighterpack list HTML pages.

Provides classes and methods to parse Lighterpack list HTML and extract structured data including list information, categories, and items with their properties (weight, quantity, consumable status, etc.).

Defined Under Namespace

Classes: Category, CategoryParser, GramConverter, Item, ItemParser, List, ListParser, Parser

Constant Summary collapse

VERSION =
'1.0.2'

Class Method Summary collapse

Class Method Details

.parse_url(url) ⇒ Object

Convenience method to parse a Lighterpack URL



20
21
22
# File 'lib/lighterpack_parser.rb', line 20

def self.parse_url(url)
  Parser.new(url: url).parse
end